@@ -22,6 +22,7 @@ from narwhals._utils import (
     generate_temporary_column_name,
     not_implemented,
     parse_columns_to_drop,
+    to_pyarrow_table,
     zip_strict,
 )
 from narwhals.exceptions import InvalidOperationError
@@ -47,7 +48,7 @@ if TYPE_CHECKING:
     from narwhals._utils import Version, _LimitedContext
     from narwhals.dataframe import LazyFrame
     from narwhals.dtypes import DType
-    from narwhals.typing import JoinStrategy, LazyUniqueKeepStrategy
+    from narwhals.typing import JoinStrategy, UniqueKeepStrategy
 
     SQLFrameDataFrame = BaseDataFrame[Any, Any, Any, Any, Any]
 
@@ -184,7 +185,7 @@ class SparkLikeLazyFrame(
             pa_schema = self._to_arrow_schema()
             return pa.Table.from_pandas(self.native.toPandas(), schema=pa_schema)
         else:
-            return self.native.toArrow()
+            return to_pyarrow_table(self.native.toArrow())
 
     def _iter_columns(self) -> Iterator[Column]:
         for col in self.columns:
@@ -366,21 +367,33 @@ class SparkLikeLazyFrame(
         )
 
     def unique(
-        self, subset: Sequence[str] | None, *, keep: LazyUniqueKeepStrategy
+        self,
+        subset: Sequence[str] | None,
+        *,
+        keep: UniqueKeepStrategy,
+        order_by: Sequence[str] | None,
     ) -> Self:
-        if subset and (error := self._check_columns_exist(subset)):
+        subset_ = subset or self.columns
+        if error := self._check_columns_exist(subset_):
             raise error
-        subset = list(subset) if subset else None
+        tmp_name = generate_temporary_column_name(8, self.columns, prefix="row_index_")
+        window = self._Window.partitionBy(subset_)
+        if order_by and keep == "last":
+            window = window.orderBy(*[self._F.desc_nulls_last(x) for x in order_by])
+        elif order_by:
+            window = window.orderBy(*[self._F.asc_nulls_first(x) for x in order_by])
+        else:
+            window = window.orderBy(self._F.lit(1))
         if keep == "none":
-            tmp = generate_temporary_column_name(8, self.columns)
-            window = self._Window.partitionBy(subset or self.columns)
-            df = (
-                self.native.withColumn(tmp, self._F.count("*").over(window))
-                .filter(self._F.col(tmp) == self._F.lit(1))
-                .drop(self._F.col(tmp))
-            )
-            return self._with_native(df)
-        return self._with_native(self.native.dropDuplicates(subset=subset))
+            expr = self._F.count("*").over(window)
+        else:
+            expr = self._F.row_number().over(window)
+        df = (
+            self.native.withColumn(tmp_name, expr)
+            .filter(self._F.col(tmp_name) == self._F.lit(1))
+            .drop(tmp_name)
+        )
+        return self._with_native(df)
 
     def join(
         self,
